@@ -20,13 +20,13 @@
  */
 /*
   File:      basicio.cpp
-  Version:   $Rev: 810 $
+  Version:   $Rev: 839 $
   Author(s): Brad Schick (brad) <brad@robotbattle.com>
   History:   04-Dec-04, brad: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: basicio.cpp 810 2006-06-02 12:59:04Z ahuggel $");
+EXIV2_RCSID("@(#) $Id: basicio.cpp 839 2006-06-28 05:36:49Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -48,6 +48,9 @@ EXIV2_RCSID("@(#) $Id: basicio.cpp 810 2006-06-02 12:59:04Z ahuggel $");
 #include <cstdlib>                      // for alloc(), realloc(), free()
 #include <sys/types.h>                  // for stat()
 #include <sys/stat.h>                   // for stat()
+#ifdef EXV_HAVE_SYS_MMAN_H
+# include <sys/mman.h>                  // for mmap() and munmap()
+#endif
 #ifdef EXV_HAVE_PROCESS_H
 # include <process.h>
 #endif
@@ -64,15 +67,57 @@ EXIV2_RCSID("@(#) $Id: basicio.cpp 810 2006-06-02 12:59:04Z ahuggel $");
 namespace Exiv2 {
 
     FileIo::FileIo(const std::string& path)
-        : path_(path), fp_(0), opMode_(opSeek)
+        : path_(path), fp_(0), opMode_(opSeek), 
+          pMappedArea_(0), mappedLength_(0), isMalloced_(false)
     {
     }
 
     FileIo::~FileIo()
     {
+        munmap();
         close();
     }
 
+    void FileIo::munmap()
+    {
+        if (pMappedArea_ != 0) {
+#if defined EXV_HAVE_MMAP && defined EXV_HAVE_MUNMAP
+            if (::munmap(pMappedArea_, mappedLength_) != 0) {
+                throw Error(2, path_, strError(), "munmap");
+            }
+#else
+            if (isMalloced_) {
+                delete[] pMappedArea_;
+                isMalloced_ = false;
+            }
+#endif
+        }
+        pMappedArea_ = 0;
+        mappedLength_ = 0;
+    }
+
+    const byte* FileIo::mmap()
+    {
+        assert(fp_ != 0);
+        munmap();
+        mappedLength_ = size();
+#if defined EXV_HAVE_MMAP && defined EXV_HAVE_MUNMAP
+        void* rc = ::mmap(0, mappedLength_, PROT_READ, MAP_SHARED, fileno(fp_), 0);
+        if (MAP_FAILED == rc) {
+            throw Error(2, path_, strError(), "mmap");
+        }
+        pMappedArea_ = static_cast<byte*>(rc);
+#else
+        // Workaround for platforms without mmap: Read the file into memory
+        DataBuf buf(static_cast<long>(mappedLength_));
+        read(buf.pData_, buf.size_);
+        if (error() || eof()) throw Error(2, path_, strError(), "FileIo::mmap");
+        pMappedArea_ = buf.release().first;
+        isMalloced_ = true;
+#endif
+        return pMappedArea_;
+    }
+
     BasicIo::AutoPtr FileIo::temporary() const
     {
         BasicIo::AutoPtr basicIo;
@@ -105,21 +150,15 @@ namespace Exiv2 {
         opMode_ = opMode;
 
         bool reopen = true;
-        std::string mode = "r+b";
-
         switch(opMode) {
         case opRead:
             // Flush if current mode allows reading, else reopen (in mode "r+b"
             // as in this case we know that we can write to the file)
-            if (   openMode_[0] == 'r'
-                || openMode_.substr(0, 2) == "w+"
-                || openMode_.substr(0, 2) == "a+") reopen = false;
+            if (openMode_[0] == 'r' || openMode_[1] == '+') reopen = false;
             break;
         case opWrite:
             // Flush if current mode allows writing, else reopen
-            if (   openMode_.substr(0, 2) == "r+"
-                || openMode_[0] == 'w'
-                || openMode_[0] == 'a') reopen = false;
+            if (openMode_[0] != 'r' || openMode_[1] == '+') reopen = false;
             break;
         case opSeek:
             reopen = false;
@@ -139,7 +178,7 @@ namespace Exiv2 {
         // Reopen the file
         long offset = ftell(fp_);
         if (offset == -1) return -1;
-        if (open(mode) != 0) return 1;
+        if (open("r+b") != 0) return 1;
         return fseek(fp_, offset, SEEK_SET);
     }
 
@@ -245,7 +284,8 @@ namespace Exiv2 {
 
     long FileIo::size() const
     {
-        if (fp_ != 0) {
+        // Flush and commit only if the file is open for writing
+        if (fp_ != 0 && (openMode_[0] != 'r' || openMode_[1] == '+')) {
             fflush(fp_);
 #if defined WIN32 && !defined __CYGWIN__
             // This is required on msvcrt before stat after writing to a file
