@@ -21,7 +21,7 @@
 /*!
   @file    basicio.hpp
   @brief   Simple binary IO abstraction
-  @version $Rev: 810 $
+  @version $Rev: 839 $
   @author  Brad Schick (brad)
            <a href="mailto:brad@robotbattle.com">brad@robotbattle.com</a>
   @date    04-Dec-04, brad: created
@@ -172,6 +172,19 @@ namespace Exiv2 {
               Nonzero if failure;
          */
         virtual int seek(long offset, Position pos) = 0;
+        /*!
+          @brief Direct access to the IO data. For files, this is done by
+                 mapping the file into the process's address space; for
+                 memory blocks, this allows direct access to the memory 
+                 block.
+
+          Todo: This is currently only for read access.
+         */
+        virtual const byte* mmap() =0;
+        /*!
+          @brief Remove a mapping established with mmap().
+         */
+        virtual void  munmap() =0;
         //@}
 
         //! @name Accessors
@@ -393,6 +406,14 @@ namespace Exiv2 {
                  Nonzero if failure;
          */
         virtual int seek(long offset, Position pos);
+        /*!
+          @brief Map the file into the process's address space. The file must
+                 be open before mmap() is called.
+          @note  The returned pointer is valid only as long as the MemIo object
+                 is in scope.
+         */
+        virtual const byte* mmap();
+        virtual void  munmap();
         //@}
 
         //! @name Accessors
@@ -446,6 +467,10 @@ namespace Exiv2 {
         FILE *fp_;
         OpMode opMode_;
 
+        byte* pMappedArea_;
+        size_t mappedLength_;
+        bool isMalloced_;               //!< Is the mapped area allocated?
+
         // METHODS
         /*!
           @brief Switch to a new access mode, reopening the file if needed.
@@ -589,6 +614,16 @@ namespace Exiv2 {
                  Nonzero if failure;
          */
         virtual int seek(long offset, Position pos);
+        /*!
+          @brief Allow direct access to the underlying data buffer. The buffer
+                 is not protected against write access except for the const
+                 specifier.
+          @note  The application must ensure that the memory pointed to by the 
+                 returned pointer remains valid and allocated as long as the 
+                 MemIo object is in scope.
+         */
+        virtual const byte* mmap() { return data_; }
+        virtual void  munmap() {}
         //@}
 
         //! @name Accessors
