@@ -20,7 +20,7 @@
  */
 /*
   File   : canonmn.cpp
-  Version: $Rev: 871 $
+  Version: $Rev: 986 $
   Authors: Andreas Huggel (ahu) <ahuggel@gmx.net>
            David Cannings (dc) <david@edeca.net>
   Credits: EXIF MakerNote of Canon by David Burren <http://www.burren.cx/david/canon.html>
@@ -28,7 +28,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: canonmn.cpp 871 2006-08-30 16:57:39Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: canonmn.cpp 986 2006-11-21 15:43:11Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -102,6 +102,11 @@ namespace Exiv2 {
         TagInfo(0xffff, "(UnknownCanonMakerNoteTag)", "(UnknownCanonMakerNoteTag)", "Unknown CanonMakerNote tag", canonIfdId, makerTags, invalidTypeId, printValue)
     };
 
+    const TagInfo* CanonMakerNote::tagList()
+    {
+        return tagInfo_;
+    }
+
     //! Macro, tag 0x0001
     extern const TagDetails canonCsMacro[] = {
         { 1, "On"  },
@@ -368,6 +373,11 @@ namespace Exiv2 {
         TagInfo(0xffff, "(UnknownCanonCsTag)", "(UnknownCanonCsTag)", "Unknown Canon Camera Settings 1 tag", canonCsIfdId, makerTags, invalidTypeId, printValue)
     };
 
+    const TagInfo* CanonMakerNote::tagListCs()
+    {
+        return tagInfoCs_;
+    }
+
     //! WhiteBalance, tag 0x0007
     extern const TagDetails canonSiWhiteBalance[] = {
         {  0, "Auto"                        },
@@ -449,6 +459,11 @@ namespace Exiv2 {
         TagInfo(0xffff, "(UnknownCanonSiTag)", "(UnknownCanonSiTag)", "Unknown Canon Camera Settings 2 tag", canonSiIfdId, makerTags, invalidTypeId, printValue)
     };
 
+    const TagInfo* CanonMakerNote::tagListSi()
+    {
+        return tagInfoSi_;
+    }
+
     //! PanoramaDirection, tag 0x0005
     extern const TagDetails canonPaDirection[] = {
         { 0, "Left to right"          },
@@ -466,6 +481,11 @@ namespace Exiv2 {
         TagInfo(0xffff, "(UnknownCanonCs2Tag)", "(UnknownCanonCs2Tag)", "Unknown Canon Panorama tag", canonPaIfdId, makerTags, invalidTypeId, printValue)
     };
 
+    const TagInfo* CanonMakerNote::tagListPa()
+    {
+        return tagInfoPa_;
+    }
+
     // Canon Custom Function Tag Info
     const TagInfo CanonMakerNote::tagInfoCf_[] = {
         TagInfo(0x0001, "NoiseReduction", "NoiseReduction", "Long exposure noise reduction", canonCfIfdId, makerTags, unsignedShort, printValue),
@@ -487,6 +507,11 @@ namespace Exiv2 {
         TagInfo(0xffff, "(UnknownCanonCfTag)", "(UnknownCanonCfTag)", "Unknown Canon Custom Function tag", canonCfIfdId, makerTags, invalidTypeId, printValue)
     };
 
+    const TagInfo* CanonMakerNote::tagListCf()
+    {
+        return tagInfoCf_;
+    }
+
     //! AFPointsUsed, tag 0x0016
     extern const TagDetailsBitmask canonPiAFPointsUsed[] = {
         { 0x01, "right"     },
@@ -523,6 +548,10 @@ namespace Exiv2 {
         TagInfo(0xffff, "(UnknownCanonPiTag)", "(UnknownCanonPiTag)", "Unknown Canon Picture Info tag", canonPiIfdId, makerTags, invalidTypeId, printValue)
     };
 
+    const TagInfo* CanonMakerNote::tagListPi()
+    {
+        return tagInfoPi_;
+    }
 
     int CanonMakerNote::read(const byte* buf,
                              long len,
