@@ -2,13 +2,13 @@
 /*!
   @file    doxygen.hpp
   @brief   Additional documentation, this file contains no source code
-  @version $Rev: 878 $
+  @version $Rev: 991 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    07-Feb-04, ahu: created
  */
 /*!
-  @mainpage Exif and IPTC metadata manipulation library and tools v0.11
+  @mainpage Exif and IPTC metadata library and tools v0.12
 
   @section overview Exiv2 Overview
 
@@ -82,12 +82,12 @@ bug tracking system</a>.</p>
 
   @verbatim $ svn checkout svn://dev.robotbattle.com/exiv2/trunk . @endverbatim
 
-  <p>To download the test data and test drivers for version 0.11 from
-  the repository, change to your local exiv2-0.11 directory and use the
+  <p>To download the test data and test drivers for version 0.12 from
+  the repository, change to your local exiv2-0.12 directory and use the
   following command:
   </p>
 
-  @verbatim $ svn export svn://dev.robotbattle.com/exiv2/tags/0.11/test @endverbatim
+  @verbatim $ svn export svn://dev.robotbattle.com/exiv2/tags/0.12/test @endverbatim
 
   <P>If you'd like to contribute code, please <A HREF="mailto:ahuggel@gmx.net">contact me</A>.
 
