@@ -21,7 +21,7 @@
 /*!
   @file    exif.hpp
   @brief   Encoding and decoding of Exif data
-  @version $Rev: 769 $
+  @version $Rev: 994 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    09-Jan-04, ahu: created
@@ -511,7 +511,7 @@ namespace Exiv2 {
         /*!
           @brief Write the Exif data to a data buffer, which is returned.  The
                  caller owns this copy and %DataBuf ensures that it will be
-                 deleted.  The copied data starts with the TIFF header.
+                 deleted. The copied data starts with the TIFF header.
 
           Tries to update the original data buffer and write it back with
           minimal changes, in a 'non-intrusive' fashion, if possible. In this
@@ -526,6 +526,9 @@ namespace Exiv2 {
           the Exif data is updated with the metadata from the actual thumbnail
           image (overriding existing metadata).
 
+          @note If there is no Exif data to write, the buffer is empty, i.e.,
+          no TIFF header is written in this case.
+
           @return A %DataBuf containing the Exif data.
          */
         DataBuf copy();
@@ -573,7 +576,7 @@ namespace Exiv2 {
           @brief Delete all Exifdatum instances resulting in an empty container.
                  Note that this also removes thumbnails.
          */
-        void clear() { eraseThumbnail(); exifMetadata_.clear(); }
+        void clear();
         //! Sort metadata by key
         void sortByKey();
         //! Sort metadata by tag
