@@ -22,13 +22,13 @@
   Abstract:  Command line program to display and manipulate image %Exif data
 
   File:      exiv2.cpp
-  Version:   $Rev: 875 $
+  Version:   $Rev: 983 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   10-Dec-03, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: exiv2.cpp 875 2006-09-12 15:03:34Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: exiv2.cpp 983 2006-11-16 14:42:38Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -259,8 +259,11 @@ void Params::help(std::ostream& os) const
        << "   -e tgt  Extract target(s) for the 'extract' action. Possible targets\n"
        << "           are the same as those for the -d option.\n"
        << "   -r fmt  Filename format for the 'rename' action. The format string\n"
-       << "           follows strftime(3). Default filename format is "
-       <<             format_ << ".\n"
+       << "           follows strftime(3). The following keywords are supported:\n"
+       << "             :basename:   - original filename without extension\n"
+       << "             :dirname:    - name of the directory holding the original file\n"
+       << "             :parentname: - name of parent directory\n"
+       << "           Default filename format is " << format_ << ".\n"
        << "   -c txt  Jpeg comment string to set in the image.\n"
        << "   -m file Command file for the modify action. The format for commands is\n"
        << "           set|add|del <key> [[<type>] <value>].\n"
