@@ -20,7 +20,7 @@
  */
 /*
   File:      fujimn.cpp
-  Version:   $Rev: 874 $
+  Version:   $Rev: 986 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   18-Feb-04, ahu: created
              07-Mar-04, ahu: isolated as a separate component
@@ -31,7 +31,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: fujimn.cpp 874 2006-09-07 15:57:45Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: fujimn.cpp 986 2006-11-21 15:43:11Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -163,6 +163,11 @@ namespace Exiv2 {
         TagInfo(0xffff, "(UnknownFujiMakerNoteTag)", "(UnknownFujiMakerNoteTag)", "Unknown FujiMakerNote tag", fujiIfdId, makerTags, invalidTypeId, printValue)
     };
 
+    const TagInfo* FujiMakerNote::tagList()
+    {
+        return tagInfo_;
+    }
+
     FujiMakerNote::FujiMakerNote(bool alloc)
         : IfdMakerNote(fujiIfdId, alloc)
     {
