@@ -24,7 +24,7 @@
            in Appendix 4: Makernote of Fujifilm of the document
            <a href="http://park2.wakwak.com/%7Etsuruzoh/Computer/Digicams/exif-e.html">
            Exif file format</a> by TsuruZoh Tachibanaya
-  @version $Rev: 851 $
+  @version $Rev: 986 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    11-Feb-04, ahu: created
@@ -116,6 +116,8 @@ namespace Exiv2 {
         int checkHeader() const;
         AutoPtr create(bool alloc =true) const;
         AutoPtr clone() const;
+        //! Return read-only list of built-in Fujifilm tags
+        static const TagInfo* tagList();
         //@}
 
         //! @cond IGNORE
