@@ -20,14 +20,14 @@
  */
 /*
   File:      ifd.cpp
-  Version:   $Rev: 859 $
+  Version:   $Rev: 979 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   26-Jan-04, ahu: created
              11-Feb-04, ahu: isolated as a component
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: ifd.cpp 859 2006-08-13 14:55:39Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: ifd.cpp 979 2006-11-16 11:14:18Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -325,11 +325,22 @@ namespace Exiv2 {
 #endif
             rc = 6;
         }
+        int n = 0;
         if (rc == 0) {
             offset_ = start - shift;
-            int n = getUShort(buf + o, byteOrder);
+            n = getUShort(buf + o, byteOrder);
             o += 2;
-
+            // Sanity check with an "unreasonably" large number
+            if (n > 256) {
+#ifndef SUPPRESS_WARNINGS
+                std::cerr << "Error: " 
+                          << "Directory " << ExifTags::ifdName(ifdId_) << " with "
+                          << n << " entries considered invalid; not read.\n";
+#endif
+                rc = 6;
+            }
+        }
+        if (rc == 0) {
             for (int i = 0; i < n; ++i) {
                 if (len < o + 12) {
 #ifndef SUPPRESS_WARNINGS
@@ -472,7 +483,7 @@ namespace Exiv2 {
                 this->add(e);
             }
         }
-        if (!alloc_) pBase_ = const_cast<byte*>(buf + shift);
+        if (!alloc_) pBase_ = const_cast<byte*>(buf);
         if (rc) this->clear();
 
         return rc;
