@@ -20,13 +20,13 @@
  */
 /*
   File:      iptc.cpp
-  Version:   $Rev: 832 $
+  Version:   $Rev: 988 $
   Author(s): Brad Schick (brad) <brad@robotbattle.com>
   History:   31-July-04, brad: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: iptc.cpp 832 2006-06-21 09:16:36Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: iptc.cpp 988 2006-11-21 16:51:04Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -170,7 +170,7 @@ namespace Exiv2 {
         }
 
         return 0;
-    } // IptcData::read
+    } // IptcData::load
 
     int IptcData::readData(uint16_t dataSet, uint16_t record,
                            const byte* data, uint32_t sizeData)
