@@ -20,14 +20,14 @@
  */
 /*
   File:      mrwimage.cpp
-  Version:   $Rev: 808 $
+  Version:   $Rev: 837 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   13-May-06, ahu: created
   Credits:   See header file
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: mrwimage.cpp 808 2006-06-01 15:09:39Z ahuggel $");
+EXIV2_RCSID("@(#) $Id: mrwimage.cpp 837 2006-06-25 09:42:59Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -105,7 +105,7 @@ namespace Exiv2 {
         // not supported
     }
 
-    void MrwImage::setComment(const std::string& comment)
+    void MrwImage::setComment(const std::string& /*comment*/)
     {
         // not supported
     }
@@ -155,7 +155,8 @@ namespace Exiv2 {
         io_->read(buf.pData_, buf.size_);
         if (io_->error() || io_->eof()) throw Error(14);
 
-        TiffParser::decode(this, buf.pData_, buf.size_, TiffCreator::create);
+        TiffParser::decode(this, buf.pData_, buf.size_, 
+                           TiffCreator::create, TiffDecoder::findDecoder);
     } // MrwImage::readMetadata
 
     void MrwImage::writeMetadata()
