@@ -25,7 +25,7 @@
            Olympus.pm of <a href="http://www.sno.phy.queensu.ca/~phil/exiftool/">ExifTool</a> by Phil Harvey,<br>
            <a href="http://www.ozhiker.com/electronics/pjmt/jpeg_info/olympus_mn.html">Olympus Makernote Format Specification</a> by Evan Hunter,<br>
            email communication with <a href="mailto:wstokes@gmail.com">Will Stokes</a>
-  @version $Rev: 783 $
+  @version $Rev: 986 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @author  Will Stokes (wuz)
@@ -119,6 +119,8 @@ namespace Exiv2 {
         int checkHeader() const;
         AutoPtr create(bool alloc =true) const;
         AutoPtr clone() const;
+        //! Return read-only list of built-in Olympus tags
+        static const TagInfo* tagList();
         //@}
 
         //! @name Print functions for Olympus %MakerNote tags
