@@ -20,7 +20,7 @@
  */
 /*
   File:      sigmamn.cpp
-  Version:   $Rev: 832 $
+  Version:   $Rev: 986 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   02-Apr-04, ahu: created
   Credits:   Sigma and Foveon MakerNote implemented according to the specification
@@ -29,7 +29,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: sigmamn.cpp 832 2006-06-21 09:16:36Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: sigmamn.cpp 986 2006-11-21 15:43:11Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -89,6 +89,11 @@ namespace Exiv2 {
         TagInfo(0xffff, "(UnknownSigmaMakerNoteTag)", "(UnknownSigmaMakerNoteTag)", "Unknown SigmaMakerNote tag", sigmaIfdId, makerTags, invalidTypeId, printValue)
     };
 
+    const TagInfo* SigmaMakerNote::tagList()
+    {
+        return tagInfo_;
+    }
+
     SigmaMakerNote::SigmaMakerNote(bool alloc)
         : IfdMakerNote(sigmaIfdId, alloc)
     {
