@@ -20,13 +20,13 @@
  */
 /*
   File:      sonymn.cpp
-  Version:   $Rev: 832 $
+  Version:   $Rev: 986 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   18-Apr-05, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: sonymn.cpp 832 2006-06-21 09:16:36Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: sonymn.cpp 986 2006-11-21 15:43:11Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -71,6 +71,11 @@ namespace Exiv2 {
         TagInfo(0xffff, "(UnknownSonyMakerNoteTag)", "Unknown SonyMakerNote tag", "Unknown SonyMakerNote tag", sonyIfdId, makerTags, invalidTypeId, printValue)
     };
 
+    const TagInfo* SonyMakerNote::tagList()
+    {
+        return tagInfo_;
+    }
+
     SonyMakerNote::SonyMakerNote(bool alloc)
         : IfdMakerNote(sonyIfdId, alloc, false)
     {
