@@ -21,7 +21,7 @@
 /*!
   @file    sonymn.hpp
   @brief   Basic Sony MakerNote implementation
-  @version $Rev: 669 $
+  @version $Rev: 986 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    18-Apr-05, ahu: created
@@ -113,6 +113,8 @@ namespace Exiv2 {
         int checkHeader() const;
         AutoPtr create(bool alloc =true) const;
         AutoPtr clone() const;
+        //! Return read-only list of built-in Sony tags
+        static const TagInfo* tagList();
         //@}
 
         //! @cond IGNORE
