@@ -3,13 +3,13 @@
   Abstract:  Print a simple comma separated list of tags defined in Exiv2
 
   File:      taglist.cpp
-  Version:   $Rev: 754 $
+  Version:   $Rev: 858 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   07-Jan-04, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: taglist.cpp 754 2006-05-05 17:38:12Z ahuggel $");
+EXIV2_RCSID("@(#) $Id: taglist.cpp 858 2006-08-13 06:06:05Z ahuggel $")
 
 #include "makernote.hpp"
 #include "tags.hpp"
@@ -58,7 +58,7 @@ try {
     }
     if (rc) {
         std::cout << "Usage: " << argv[0]
-                  << " [Exif|Canon|CanonCs1|CanonCs2|CanonCf|Fujifilm|Nikon1|Nikon2|Nikon3|Olympus|Sigma|Sony|Iptc]\n"
+                  << " [Exif|Canon|CanonCs|CanonSi|CanonCf|Fujifilm|Nikon1|Nikon2|Nikon3|Olympus|Sigma|Sony|Iptc]\n"
                   << "Print Exif tags, MakerNote tags, or Iptc datasets\n";
     }
     return rc;
