@@ -21,7 +21,7 @@
 /*!
   @file    tags.hpp
   @brief   Exif tag and type information
-  @version $Rev: 872 $
+  @version $Rev: 986 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    15-Jan-04, ahu: created<BR>
@@ -272,6 +272,14 @@ namespace Exiv2 {
                                       uint16_t tag,
                                       IfdId ifdId,
                                       const Value& value);
+        //! Return read-only list of built-in IFD0/1 tags
+        static const TagInfo* ifdTagList();
+        //! Return read-only list of built-in Exif IFD tags
+        static const TagInfo* exifTagList();
+        //! Return read-only list of built-in IOP tags
+        static const TagInfo* iopTagList();
+        //! Return read-only list of built-in GPS tags
+        static const TagInfo* gpsTagList();
         //! Print a list of all standard Exif tags to output stream
         static void taglist(std::ostream& os);
         //! Print a list of all tags related to one makernote %IfdId
@@ -432,7 +440,13 @@ namespace Exiv2 {
     std::ostream& printLong(std::ostream& os, const Value& value);
     //! Print a Rational or URational value in floating point format
     std::ostream& printFloat(std::ostream& os, const Value& value);
+    //! Print a longitude or latitude value
+    std::ostream& printDegrees(std::ostream& os, const Value& value);
 
+    //! Print GPS altitude
+    std::ostream& print0x0006(std::ostream& os, const Value& value);
+    //! Print GPS timestamp
+    std::ostream& print0x0007(std::ostream& os, const Value& value);
     //! Print the copyright
     std::ostream& print0x8298(std::ostream& os, const Value& value);
     //! Print the exposure time
