@@ -20,8 +20,8 @@
  */
 /*!
   @file    tiffcomposite.hpp
-  @brief
-  @version $Rev: 808 $
+  @brief   Various classes used in a TIFF composite structure
+  @version $Rev: 837 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    11-Apr-06, ahu: created
@@ -32,6 +32,7 @@
 // *****************************************************************************
 // included header files
 #include "image.hpp"                            // for Blob
+#include "tifffwd.hpp"
 #include "types.hpp"
 
 // + standard includes
@@ -44,17 +45,6 @@
 // namespace extensions
 namespace Exiv2 {
 
-// *****************************************************************************
-// class declarations
-
-    class Value;
-    class TiffVisitor;
-    class TiffReader;
-    class TiffMetadataDecoder;
-    class TiffPrinter;
-    class TiffIfdMakernote;
-    struct TiffStructure;
-
 // *****************************************************************************
 // class definitions
 
@@ -152,10 +142,10 @@ namespace Exiv2 {
         //! @name Manipulators
         //@{
         //! Implements addChild(). The default implementation does nothing.
-        virtual void doAddChild(AutoPtr tiffComponent) {}
+        virtual void doAddChild(AutoPtr /*tiffComponent*/) {}
 
         //! Implements addNext(). The default implementation does nothing.
-        virtual void doAddNext(AutoPtr tiffComponent) {}
+        virtual void doAddNext(AutoPtr /*tiffComponent*/) {}
 
         //! Implements accept()
         virtual void doAccept(TiffVisitor& visitor) =0;
@@ -173,12 +163,6 @@ namespace Exiv2 {
 
     }; // class TiffComponent
 
-    /*!
-      Type for a function pointer for a function to create a TIFF component.
-     */
-    typedef TiffComponent::AutoPtr (*NewTiffCompFct)(uint16_t tag,
-                                                     const TiffStructure* ts);
-
     /*!
       @brief Data structure used as a row (element) of a table (array)
              describing the TIFF structure of an image format for reading and
@@ -207,11 +191,37 @@ namespace Exiv2 {
         uint16_t g_;                    //!< %Group
     };
 
-    /*!
-      Type for a factory function to create new TIFF components.
-     */
-    typedef TiffComponent::AutoPtr (*TiffCompFactoryFct)(uint32_t extendedTag,
-                                                         uint16_t group);
+    //! TIFF decoder table for functions to decode special cases
+    struct TiffDecoderInfo {
+        struct Key;
+        /*!
+          @brief Compare a TiffDecoderInfo with a TiffDecoderInfo::Key.
+                 The two are equal if TiffDecoderInfo::make_ equals a substring
+                 of the key of the same size. E.g., decoder info = "OLYMPUS",
+                 key = "OLYMPUS OPTICAL CO.,LTD" (found in the image) match,
+                 the extendedTag is Tag::all or equal to the extended tag of the
+                 key, and the group is equal to that of the key.
+         */
+        bool operator==(const Key& key) const;
+        //! Return the tag corresponding to the extended tag
+        uint16_t tag() const { return static_cast<uint16_t>(extendedTag_ & 0xffff); }
+
+        // DATA
+        const char* make_;        //!< Camera make for which this decoder function applies
+        uint32_t    extendedTag_; //!< Tag (32 bit so that it can contain special tags)
+        uint16_t    group_;       //!< Group that contains the tag
+        DecoderFct  decoderFct_;  //!< Decoder function for matching tags
+
+    }; // struct TiffDecoderInfo
+
+    //! Search key for TIFF decoder structures.
+    struct TiffDecoderInfo::Key {
+        //! Constructor
+        Key(const std::string& m, uint32_t e, uint16_t g) : m_(m), e_(e), g_(g) {}
+        std::string m_;                    //!< Camera make
+        uint32_t    e_;                    //!< Extended tag
+        uint16_t    g_;                    //!< %Group
+    };
 
     /*!
       @brief This abstract base class provides the common functionality of an
@@ -606,13 +616,25 @@ namespace Exiv2 {
         return newTiffArrayElement<typeId, invalidByteOrder>(tag, ts);
     }
 
-    //! Function to create and initialize a new TIFF entry for a Jpeg thumbnail (data)
+    //! Function to create and initialize a new TIFF entry for a thumbnail (data)
+    template<uint16_t szTag, uint16_t szGroup>
     TiffComponent::AutoPtr newTiffThumbData(uint16_t tag,
-                                            const TiffStructure* ts);
+                                            const TiffStructure* ts)
+    {
+        assert(ts);
+        return TiffComponent::AutoPtr(
+            new TiffDataEntry(tag, ts->group_, szTag, szGroup));
+    }
 
-    //! Function to create and initialize a new TIFF entry for a Jpeg thumbnail (size)
+    //! Function to create and initialize a new TIFF entry for a thumbnail (size)
+    template<uint16_t dtTag, uint16_t dtGroup>
     TiffComponent::AutoPtr newTiffThumbSize(uint16_t tag,
-                                            const TiffStructure* ts);
+                                            const TiffStructure* ts)
+    {
+        assert(ts);
+        return TiffComponent::AutoPtr(
+            new TiffSizeEntry(tag, ts->group_, dtTag, dtGroup));
+    }
 
 }                                       // namespace Exiv2
 
