@@ -20,14 +20,14 @@
  */
 /*
   File:      tiffimage.cpp
-  Version:   $Rev: 797 $
+  Version:   $Rev: 838 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   15-Mar-06, ahu: created
 
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: tiffimage.cpp 797 2006-05-26 16:39:11Z ahuggel $");
+EXIV2_RCSID("@(#) $Id: tiffimage.cpp 838 2006-06-25 18:11:01Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -126,14 +126,9 @@ namespace Exiv2 {
             throw Error(33);
         }
         clearMetadata();
+        TiffParser::decode(this, io_->mmap(), io_->size(),
+                           TiffCreator::create, TiffDecoder::findDecoder);
 
-        // Read the image into a memory buffer
-        long len = io_->size();
-        DataBuf buf(len);
-        io_->read(buf.pData_, len);
-        if (io_->error() || io_->eof()) throw Error(14);
-
-        TiffParser::decode(this, buf.pData_, buf.size_, TiffCreator::create);
     } // TiffImage::readMetadata
 
     void TiffImage::writeMetadata()
