@@ -20,13 +20,13 @@
  */
 /*
   File:      tiffvisitor.cpp
-  Version:   $Rev: 854 $
+  Version:   $Rev: 943 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   11-Apr-06, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: tiffvisitor.cpp 854 2006-08-02 14:16:10Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: tiffvisitor.cpp 943 2006-11-06 15:48:14Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -36,8 +36,8 @@ EXIV2_RCSID("@(#) $Id: tiffvisitor.cpp 854 2006-08-02 14:16:10Z ahuggel $")
 # include "exv_conf.h"
 #endif
 
-#include "tiffvisitor.hpp"
-#include "tiffcomposite.hpp"
+#include "tiffcomposite.hpp"  // Do not change the order of these 2 includes,
+#include "tiffvisitor.hpp"    // see bug #487
 #include "tiffparser.hpp"
 #include "makernote2.hpp"
 #include "exif.hpp"
@@ -558,7 +558,7 @@ namespace Exiv2 {
         const uint16_t n = getUShort(p, byteOrder());
         p += 2;
         // Sanity check with an "unreasonably" large number
-        if (n > 512) {
+        if (n > 256) {
 #ifndef SUPPRESS_WARNINGS
             std::cerr << "Error: " 
                       << "Directory " << object->groupName() << " with " 
