@@ -20,13 +20,13 @@
  */
 /*
   File:      utils.cpp
-  Version:   $Rev: 832 $
+  Version:   $Rev: 983 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   08-Dec-03, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: utils.cpp 832 2006-06-21 09:16:36Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: utils.cpp 983 2006-11-16 14:42:38Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -143,4 +143,14 @@ namespace Util {
         return true;
     }
 
+    void replace(std::string& text, const std::string& searchText, const std::string& replaceText)
+    {
+        std::string::size_type index = 0;
+        while ((index = text.find(searchText, index)) != std::string::npos)
+        {
+            text.replace(index, searchText.length(), replaceText.c_str(), replaceText.length());
+            index++;
+        }
+    }
+
 }                                       // namespace Util
